/*
 * Note: this file originally auto-generated by mib2c using
 *       version $ of $ 
 *
 * $Id:$
 */
/** \page MFD helper for dot1qVlanCurrentTable
 *
 * \section intro Introduction
 * Introductory text.
 *
 */
/* standard Net-SNMP includes */
#include <net-snmp/net-snmp-config.h>
#include <net-snmp/net-snmp-features.h>
#include <net-snmp/net-snmp-includes.h>
#include <net-snmp/agent/net-snmp-agent-includes.h>

/* include our parent header */
#include "dot1qVlanCurrentTable.h"

#include <net-snmp/agent/mib_modules.h>

#include "dot1qVlanCurrentTable_interface.h"

const oid dot1qVlanCurrentTable_oid[] = { DOT1QVLANCURRENTTABLE_OID };
const int dot1qVlanCurrentTable_oid_size = OID_LENGTH(dot1qVlanCurrentTable_oid);

    dot1qVlanCurrentTable_registration  dot1qVlanCurrentTable_user_context;

void initialize_table_dot1qVlanCurrentTable(void);
void shutdown_table_dot1qVlanCurrentTable(void);


/**
 * Initializes the dot1qVlanCurrentTable module
 */
void
init_dot1qVlanCurrentTable(void)
{
    DEBUGMSGTL(("verbose:dot1qVlanCurrentTable:init_dot1qVlanCurrentTable","called\n"));

    /*
     * TODO:300:o: Perform dot1qVlanCurrentTable one-time module initialization.
     */
     
    /*
     * here we initialize all the tables we're planning on supporting
     */
    if (should_init("dot1qVlanCurrentTable"))
        initialize_table_dot1qVlanCurrentTable();

} /* init_dot1qVlanCurrentTable */

/**
 * Shut-down the dot1qVlanCurrentTable module (agent is exiting)
 */
void
shutdown_dot1qVlanCurrentTable(void)
{
    if (should_init("dot1qVlanCurrentTable"))
        shutdown_table_dot1qVlanCurrentTable();

}

/**
 * Initialize the table dot1qVlanCurrentTable 
 *    (Define its contents and how it's structured)
 */
void
initialize_table_dot1qVlanCurrentTable(void)
{
    dot1qVlanCurrentTable_registration * user_context;
    u_long flags;

    DEBUGMSGTL(("verbose:dot1qVlanCurrentTable:initialize_table_dot1qVlanCurrentTable","called\n"));

    /*
     * TODO:301:o: Perform dot1qVlanCurrentTable one-time table initialization.
     */

    /*
     * TODO:302:o: |->Initialize dot1qVlanCurrentTable user context
     * if you'd like to pass in a pointer to some data for this
     * table, allocate or set it up here.
     */
    /*
     * a netsnmp_data_list is a simple way to store void pointers. A simple
     * string token is used to add, find or remove pointers.
     */
    user_context = netsnmp_create_data_list("dot1qVlanCurrentTable", NULL, NULL);
    
    /*
     * No support for any flags yet, but in the future you would
     * set any flags here.
     */
    flags = 0;
    
    /*
     * call interface initialization code
     */
    _dot1qVlanCurrentTable_initialize_interface(user_context, flags);
} /* initialize_table_dot1qVlanCurrentTable */

/**
 * Shutdown the table dot1qVlanCurrentTable 
 */
void
shutdown_table_dot1qVlanCurrentTable(void)
{
    /*
     * call interface shutdown code
     */
    _dot1qVlanCurrentTable_shutdown_interface(&dot1qVlanCurrentTable_user_context);
}

/**
 * extra context initialization (eg default values)
 *
 * @param rowreq_ctx    : row request context
 * @param user_init_ctx : void pointer for user (parameter to rowreq_ctx_allocate)
 *
 * @retval MFD_SUCCESS  : no errors
 * @retval MFD_ERROR    : error (context allocate will fail)
 */
int
dot1qVlanCurrentTable_rowreq_ctx_init(dot1qVlanCurrentTable_rowreq_ctx *rowreq_ctx,
                           void *user_init_ctx)
{
    DEBUGMSGTL(("verbose:dot1qVlanCurrentTable:dot1qVlanCurrentTable_rowreq_ctx_init","called\n"));

    netsnmp_assert(NULL != rowreq_ctx);
    
    /*
     * TODO:210:o: |-> Perform extra dot1qVlanCurrentTable rowreq initialization. (eg DEFVALS)
     */

    return MFD_SUCCESS;
} /* dot1qVlanCurrentTable_rowreq_ctx_init */

/**
 * extra context cleanup
 *
 */
void dot1qVlanCurrentTable_rowreq_ctx_cleanup(dot1qVlanCurrentTable_rowreq_ctx *rowreq_ctx)
{
    DEBUGMSGTL(("verbose:dot1qVlanCurrentTable:dot1qVlanCurrentTable_rowreq_ctx_cleanup","called\n"));

    netsnmp_assert(NULL != rowreq_ctx);
    
    /*
     * TODO:211:o: |-> Perform extra dot1qVlanCurrentTable rowreq cleanup.
     */
} /* dot1qVlanCurrentTable_rowreq_ctx_cleanup */

/**
 * pre-request callback
 *
 *
 * @retval MFD_SUCCESS              : success.
 * @retval MFD_ERROR                : other error
 */
int
dot1qVlanCurrentTable_pre_request(dot1qVlanCurrentTable_registration * user_context)
{
    DEBUGMSGTL(("verbose:dot1qVlanCurrentTable:dot1qVlanCurrentTable_pre_request","called\n"));

    /*
     * TODO:510:o: Perform dot1qVlanCurrentTable pre-request actions.
     */

    return MFD_SUCCESS;
} /* dot1qVlanCurrentTable_pre_request */

/**
 * post-request callback
 *
 * Note:
 *   New rows have been inserted into the container, and
 *   deleted rows have been removed from the container and
 *   released.
 *
 * @param user_context
 * @param rc : MFD_SUCCESS if all requests succeeded
 *
 * @retval MFD_SUCCESS : success.
 * @retval MFD_ERROR   : other error (ignored)
 */
int
dot1qVlanCurrentTable_post_request(dot1qVlanCurrentTable_registration * user_context, int rc)
{
    DEBUGMSGTL(("verbose:dot1qVlanCurrentTable:dot1qVlanCurrentTable_post_request","called\n"));

    /*
     * TODO:511:o: Perform dot1qVlanCurrentTable post-request actions.
     */

    return MFD_SUCCESS;
} /* dot1qVlanCurrentTable_post_request */


/** @{ */
